jenkins-bot has submitted this change and it was merged. (
https://gerrit.wikimedia.org/r/309472 )
Change subject: Update VE core submodule to master (139bdf7)
......................................................................
Update VE core submodule to master (139bdf7)
New changes:
d79138b Overwrite selected content when pasting via DataTransferItem
3c4737f Ensure clipboard is never empty text
3b1339e Create dummy platform and target for tests
4d63c8e Pass text as string to insertDocument when detected as plain text
Local change:
Remove VE standalone module
Flow used to use it, but not anymore. Going forward no one should
be using it in MW.
Bug: T154020
Bug: T156302
Bug: T156498
Depends-On: I078c244ef524669da477a43f9b37c847252e5ad7
Change-Id: Ifc4be16269f819890f2dcdddbbdebf9694ad2868
---
M VisualEditor.hooks.php
M extension.json
M lib/ve
M modules/ve-mw/tests/ve.test.utils.js
4 files changed, 5 insertions(+), 24 deletions(-)
Approvals:
jenkins-bot: Verified
Jforrester: Looks good to me, approved
diff --git a/VisualEditor.hooks.php b/VisualEditor.hooks.php
index 450e91a..d421409 100644
--- a/VisualEditor.hooks.php
+++ b/VisualEditor.hooks.php
@@ -868,7 +868,6 @@
'modules/ve-mw/tests/ui/datatransferhandlers/ve.ui.MWWikitextStringTransferHandler.test.js',
'modules/ve-mw/tests/ui/datatransferhandlers/ve.ui.UrlStringTransferHandler.test.js',
// VisualEditor initialization Tests
- 'lib/ve/tests/init/ve.init.Platform.test.js',
'modules/ve-mw/tests/init/targets/ve.init.mw.DesktopArticleTarget.test.js',
// IME tests
'lib/ve/tests/ce/ve.ce.TestRunner.js',
@@ -911,7 +910,6 @@
],
'dependencies' => [
'unicodejs',
- 'ext.visualEditor.standalone',
'ext.visualEditor.core',
'ext.visualEditor.mwcore',
'ext.visualEditor.mwformatting',
diff --git a/extension.json b/extension.json
index 5eecc46..5aa0764 100644
--- a/extension.json
+++ b/extension.json
@@ -545,22 +545,6 @@
"mobile"
]
},
- "ext.visualEditor.standalone": {
- "scripts": [
- "lib/ve/src/init/sa/ve.init.sa.js",
- "lib/ve/src/init/sa/ve.init.sa.Platform.js",
- "lib/ve/src/init/sa/ve.init.sa.Target.js",
- "lib/ve/src/init/sa/ve.init.sa.DesktopTarget.js"
- ],
- "styles": [
- "lib/ve/src/init/sa/styles/ve.init.sa.css"
- ],
- "dependencies": [
- "ext.visualEditor.base",
- "jquery.i18n",
- "jquery.uls.data"
- ]
- },
"ext.visualEditor.data": {
"class": "VisualEditorDataModule"
},
diff --git a/lib/ve b/lib/ve
index e5dffec..139bdf7 160000
--- a/lib/ve
+++ b/lib/ve
@@ -1 +1 @@
-Subproject commit e5dffec5406693126f13b2de8c57c99ee8d73162
+Subproject commit 139bdf7add8149c9506f4b1eeaf5553e2eb8afeb
diff --git a/modules/ve-mw/tests/ve.test.utils.js
b/modules/ve-mw/tests/ve.test.utils.js
index d4ccb20..3b94f5e 100644
--- a/modules/ve-mw/tests/ve.test.utils.js
+++ b/modules/ve-mw/tests/ve.test.utils.js
@@ -12,9 +12,9 @@
// Prevent the target from setting up the surface immediately
ve.init.platform.initialized = $.Deferred();
- // HACK: MW targets are async and heavy, use an SA target but
- // override the global registration
- target = new ve.init.sa.Target();
+ // HACK: MW targets are async and heavy, use a DummyTarget
+ // but override the global registration
+ target = new ve.test.utils.DummyTarget();
mwTarget = new ve.init.mw.ArticleTarget();
$( '#qunit-fixture' ).append( target.$element );
@@ -22,8 +22,7 @@
ve.init.platform.initialized.resolve();
mwTarget = null;
- target.addSurface( doc );
- return target.surface;
+ return target.addSurface( doc );
};
// Unregister MW override nodes.
--
To view, visit https://gerrit.wikimedia.org/r/309472
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings
Gerrit-MessageType: merged
Gerrit-Change-Id: Ifc4be16269f819890f2dcdddbbdebf9694ad2868
Gerrit-PatchSet: 7
Gerrit-Project: mediawiki/extensions/VisualEditor
Gerrit-Branch: master
Gerrit-Owner: Esanders <[email protected]>
Gerrit-Reviewer: Bartosz DziewoĆski <[email protected]>
Gerrit-Reviewer: Esanders <[email protected]>
Gerrit-Reviewer: Jforrester <[email protected]>
Gerrit-Reviewer: jenkins-bot <>
_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits